==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/FinancialOverlayDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialSeriesDescriptionMetadata } from "./FinancialSeriesDescriptionMetadata";
/**
 * @hidden
 */
var FinancialOverlayDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(FinancialOverlayDescriptionMetadata, _super);
    function FinancialOverlayDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FinancialOverlayDescriptionMetadata.b = function (a) {
        if (FinancialOverlayDescriptionMetadata.a == null) {
            FinancialOverlayDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FinancialOverlayDescriptionMetadata.c(FinancialOverlayDescriptionMetadata.a);
        }
        if (a.j(FinancialOverlayDescriptionMetadata.a)) {
            return;
        }
        a.y(FinancialOverlayDescriptionMetadata.a);
    };
    FinancialOverlayDescriptionMetadata.c = function (a) {
        FinancialSeriesDescriptionMetadata.c(a);
        a.item("IgnoreFirst", "Number:int");
    };
    FinancialOverlayDescriptionMetadata.d = function (a) {
        FinancialOverlayDescriptionMetadata.b(a);
        a.z("FinancialOverlay", FinancialOverlayDescriptionMetadata.a);
    };
    FinancialOverlayDescriptionMetadata.$t = markType(FinancialOverlayDescriptionMetadata, 'FinancialOverlayDescriptionMetadata');
    FinancialOverlayDescriptionMetadata.a = null;
    return FinancialOverlayDescriptionMetadata;
}(Base));
export { FinancialOverlayDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/FinancialOverlayDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialSeriesDescriptionMetadata } from "./FinancialSeriesDescriptionMetadata";
/**
 * @hidden
 */
var FinancialOverlayDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(FinancialOverlayDescriptionMetadata, _super);
    function FinancialOverlayDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FinancialOverlayDescriptionMetadata.b = function (a) {
        if (FinancialOverlayDescriptionMetadata.a == null) {
            FinancialOverlayDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FinancialOverlayDescriptionMetadata.c(FinancialOverlayDescriptionMetadata.a);
        }
        if (a.k(FinancialOverlayDescriptionMetadata.a)) {
            return;
        }
        a.aa(FinancialOverlayDescriptionMetadata.a);
    };
    FinancialOverlayDescriptionMetadata.c = function (a) {
        FinancialSeriesDescriptionMetadata.c(a);
        a.item("IgnoreFirst", "Number:int");
    };
    FinancialOverlayDescriptionMetadata.d = function (a) {
        FinancialOverlayDescriptionMetadata.b(a);
        a.ab("FinancialOverlay", FinancialOverlayDescriptionMetadata.a);
    };
    FinancialOverlayDescriptionMetadata.$t = markType(FinancialOverlayDescriptionMetadata, 'FinancialOverlayDescriptionMetadata');
    FinancialOverlayDescriptionMetadata.a = null;
    return FinancialOverlayDescriptionMetadata;
}(Base));
export { FinancialOverlayDescriptionMetadata };
